==> haskell-ordered-containers-0.2.4-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-Lltema9hvAHgTCSlC32we
key:                  ordered-containers-0.2.4-Lltema9hvAHgTCSlC32we
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  56e06aa6a375dc5830ad2d438167e5d1
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-Lltema9hvAHgTCSlC32we
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-DGEtQXeqhKmCCbhJMtBsUM

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ordered-containers-0.2.4-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ordered-containers
version:              0.2.4
visibility:           public
id:                   ordered-containers-0.2.4-4T6ycs3BOXS3ROZt30LpDs
key:                  ordered-containers-0.2.4-4T6ycs3BOXS3ROZt30LpDs
license:              BSD-3-Clause
maintainer:           me@dmwit.com
author:               Daniel Wagner
synopsis:
    Set- and Map-like types that remember the order elements were inserted

category:             Data
abi:                  5e58193feaa7a0f586b0a004dbeb51a6
exposed:              True
exposed-modules:
    Data.Map.Ordered Data.Map.Ordered.Strict Data.Set.Ordered

hidden-modules:       Data.Map.Ordered.Internal Data.Map.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ordered-containers-0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ordered-containers
hs-libraries:         HSordered-containers-0.2.4-4T6ycs3BOXS3ROZt30LpDs
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.4.0-BPBogvz51gTFqjBeDWtSVb

haddock-interfaces:
    /usr/share/doc/haskell-ordered-containers/html/ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
